@@ -1,5 +1,6 @@
 # -*- coding:utf-8 -*-
 
+import collections
 
 from _emerge.Package import Package
 
@@ -27,7 +28,7 @@ def check_slotop(depstr, is_valid_flag, badsyntax, mytype,
 			token_class=portage.dep.Atom)
 	except portage.exception.InvalidDependString as e:
 		my_dep_tree = None
-		badsyntax.append(str(e))
+		badsyntax.append((mytype, str(e)))
 
 	def _traverse_tree(dep_tree, in_any_of):
 		# leaf
@@ -67,7 +68,7 @@ def _depend_checks(ebuild, pkg, portdb, qatracker, repo_metadata):
 		"java-pkg-opt-2" in ebuild.inherited,
 	inherited_wxwidgets_eclass = "wxwidgets" in ebuild.inherited
 	# operator_tokens = set(["||", "(", ")"])
-	type_list, badsyntax = [], []
+	badsyntax = []
 	for mytype in Package._dep_keys + ("LICENSE", "PROPERTIES", "PROVIDE"):
 		mydepstr = ebuild.metadata[mytype]
 
@@ -83,7 +84,7 @@ def _depend_checks(ebuild, pkg, portdb, qatracker, repo_metadata):
 				is_valid_flag=pkg.iuse.is_valid_flag, token_class=token_class)
 		except portage.exception.InvalidDependString as e:
 			atoms = None
-			badsyntax.append(str(e))
+			badsyntax.append((mytype, str(e)))
 
 		if atoms and mytype.endswith("DEPEND"):
 			if runtime and \
@@ -156,27 +157,25 @@ def _depend_checks(ebuild, pkg, portdb, qatracker, repo_metadata):
 				check_missingslot(atom, mytype, ebuild.eapi, portdb, qatracker,
 					ebuild.relative_path, ebuild.metadata)
 
-		type_list.extend([mytype] * (len(badsyntax) - len(type_list)))
-
 		if runtime:
 			check_slotop(mydepstr, pkg.iuse.is_valid_flag,
 				badsyntax, mytype, qatracker, ebuild.relative_path)
 
-	for m, b in zip(type_list, badsyntax):
+	baddepsyntax = False
+	dedup = collections.defaultdict(set)
+	for m, b in badsyntax:
+		if b in dedup[m]:
+			continue
+		dedup[m].add(b)
+
 		if m.endswith("DEPEND"):
+			baddepsyntax = True
 			qacat = "dependency.syntax"
 		else:
 			qacat = m + ".syntax"
 		qatracker.add_error(
 			qacat, "%s: %s: %s" % (ebuild.relative_path, m, b))
 
-	# data required for some other tests
-	badlicsyntax = len([z for z in type_list if z == "LICENSE"])
-	badprovsyntax = len([z for z in type_list if z == "PROVIDE"])
-	baddepsyntax = len(type_list) != badlicsyntax + badprovsyntax
-	badlicsyntax = badlicsyntax > 0
-	#badprovsyntax = badprovsyntax > 0
-
 	# Parse the LICENSE variable, remove USE conditions and flatten it.
 	licenses = portage.dep.use_reduce(
 		ebuild.metadata["LICENSE"], matchall=1, flat=True)
